@@ -145,6 +145,22 @@ void Summary::readPool( const ResPool & pool )
     }
   }
 
+  if ( hasViewOption( PATCH_REBOOT_RULES ) ) {
+    // bsc#1183268: Patch reboot-needed flag overrules included packages.
+    // Work around the unfortunate case, where a maintenance patch's metadata
+    // does not request a reboot, while some included package does.
+    // The 'patch --skip-interactive' command operates based on the maintenance
+    // metadata and skips patches that require a reboot. In this case we suppress
+    // the reboot needed hint of included packages in order not to confuse the user.
+    // The decision is debatable, but as long as maintenance provides a reboot-needed
+    // flag for Patches, we will not overrule it by computing it from the included packages.
+    if ( not _need_reboot_patch && _need_reboot_nonpatch ) {
+      MIL << "PATCH_REBOOT_RULES overrules " << _rebootNeeded[ResKind::package].size() << " packages." << endl;
+      _rebootNeeded[ResKind::package].clear();
+      _need_reboot_nonpatch = false;
+    }
+  }
+
   for ( const auto & spkg : Zypper::instance().runtimeData().srcpkgs_to_install )
   { to_be_installed[ResKind::srcpackage].insert(spkg); }
 
@@ -1403,6 +1419,7 @@ void Summary::writePackageCounts( std::ostream & out )
     return;
 
   std::ostringstream s;
+  s << endl;
   bool gotcha = false;
   unsigned count;
   KindToResPairSet::const_iterator i;
@@ -1521,6 +1538,8 @@ void Summary::writePackageCounts( std::ostream & out )
 
 void Summary::dumpTo( std::ostream & out )
 {
+  // bsc#1180077: Take care nothing is written to stdout/err if there's
+  //              nothing todo. At least not if --quiet is used.
   Zypper & zypper( Zypper::instance() );
 
   struct SetColor
@@ -1577,7 +1596,6 @@ void Summary::dumpTo( std::ostream & out )
     writeSupportNeedACC( out );
   }
   writeRebootNeeded( out );
-  out << endl;
   writePackageCounts( out );
   writeDownloadAndInstalledSizeSummary( out );
   if ( _need_restart && zypper.runtimeData().plain_patch_command && !(_viewop & UPDATESTACK_ONLY) )
@@ -1623,6 +1641,7 @@ void Summary::writeXmlResolvableList( std::ostream & out, const KindToResPairSet
       out << " name=\"" << res->name() << "\"";
       out << " edition=\"" << res->edition() << "\"";
       out << " arch=\"" << res->arch() << "\"";
+      out << " repository=\"" << res->repoInfo().alias() << "\"";
       if ( rold )
       {
         out << " edition-old=\"" << rold->edition() << "\"";
