@@ -320,14 +320,14 @@ FillPatchesTable::FillPatchesTable( Table & table_r, const PatchHistoryData & hi
 , _historyData( historyData_r )
 {
   table_r << ( TableHeader()
-  << _("Repository")
-  << _("Name")
-  << _("Category")
-  << _("Severity")
-  << _("Interactive")
-  << _("Status")
-  << ColumnIf( bool(_historyData), [](){ return _("Since"); } )
-  << _("Summary")
+  << N_("Repository")
+  << N_("Name")
+  << N_("Category")
+  << N_("Severity")
+  << N_("Interactive")
+  << N_("Status")
+  << ColumnIf( bool(_historyData), [](){ return N_("Since"); } )
+  << N_("Summary")
   );
   table_r.defaultSortColumn( 1 );	// by Name
 }
@@ -361,15 +361,15 @@ FillPatchesTableForIssue::FillPatchesTableForIssue( Table & table_r, const Patch
 {
   table_r << ( TableHeader()
   //<< _("Repository")
-  << _("Issue")
-  << _("No.")
-  << _("Patch")	// Name
-  << _("Category")
-  << _("Severity")
-  << _("Interactive")
-  << _("Status")
-  << ColumnIf( bool(_historyData), [](){ return _("Since"); } )
-  << _("Summary")
+  << N_("Issue")
+  << N_("No.")
+  << N_("Patch")	// Name
+  << N_("Category")
+  << N_("Severity")
+  << N_("Interactive")
+  << N_("Status")
+  << ColumnIf( bool(_historyData), [](){ return N_("Since"); } )
+  << N_("Summary")
   );
   table_r.defaultSortColumn( 2 );	// by Name
 }
@@ -493,8 +493,12 @@ namespace
 } // namespace
 ///////////////////////////////////////////////////////////////////
 
-Url make_obs_url( const std::string & obsuri, const Url & base_url, const std::string & default_platform )
+Url make_obs_url( const std::string & obsuri )
 {
+  Zypper & zypper { Zypper::instance() };
+  const Url base_url { zypper.config().obs_baseUrl };
+  const std::string default_platform { zypper.config().obs_platform };
+
   // obs-server ==> < base_url, default_platform >
   static std::map<std::string, std::pair<Url,std::string>> wellKnownServers({
     { "build.opensuse.org",	{ Url("https://download.opensuse.org/repositories/"),	std::string() } }
@@ -533,8 +537,6 @@ Url make_obs_url( const std::string & obsuri, const Url & base_url, const std::s
 
     if ( platform.empty() )
     {
-      Zypper & zypper( Zypper::instance() );
-
       if ( default_platform.empty() )
       {
 	// Try to guess platform from baseproduct....
@@ -545,14 +547,13 @@ Url make_obs_url( const std::string & obsuri, const Url & base_url, const std::s
 			     // translators: don't translate '<platform>'
 	  zypper.out().error(_("Unable to guess a value for <platform>."),
 			     _("Please use obs://<project>/<platform>") );
-	  zypper.out().info(str::form(_("Example: %s"), "obs://server:http/openSUSE_11.3"));
+	  zypper.out().info(str::form(_("Example: %s"), "obs://zypp:Head/openSUSE_Factory"));
 	  return Url();	// FAIL!
 	}
 
 	platform = pdata.name().asString();
 	if ( platform == "openSUSE"  )
 	{
-
 	  if ( pdata.productline() == "Leap" )
 	    platform += "_Leap_$releasever";
 	  else if ( str::containsCI( pdata.summary(), "Tumbleweed" ) )
@@ -560,6 +561,11 @@ Url make_obs_url( const std::string & obsuri, const Url & base_url, const std::s
 	  else
 	    platform += "_$releasever";
 	}
+	else if ( platform == "MicroOS" && pdata.vendor() == "openSUSE" )
+	{
+	  // bsc#1153687 Hotfix
+	  platform = "openSUSE_Tumbleweed";
+	}
 	else
 	  platform += "_$releasever";
 
@@ -581,8 +587,8 @@ Url make_obs_url( const std::string & obsuri, const Url & base_url, const std::s
   }
   else
   {
-    Zypper::instance().out().error(_("Invalid OBS URI."), _("Correct form is obs://<project>/[platform]"));
-    Zypper::instance().out().info(str::form(_("Example: %s"), "obs://server:http/openSUSE_11.3"));
+    zypper.out().error(_("Invalid OBS URI."), _("Correct form is obs://<project>/[platform]"));
+    zypper.out().info(str::form(_("Example: %s"), "obs://zypp:Head/openSUSE_Factory"));
   }
 
   return Url();
@@ -807,11 +813,11 @@ bool iType( const ui::Selectable::constPtr & sel_r )
 
 const char * computeStatusIndicator( const PoolItem & pi_r, ui::Selectable::constPtr sel_r, bool * iType_r )
 {
-  static const char * _[] = { " ",  " R", " l" };	// not installed / not relevant
-  static const char * i[] = { "i",  "iR", "il" };	// installed     / satisfied
-  static const char * I[] = { "i+", "iR", "il" };	// user installed
-  static const char * v[] = { "v",  "vR", "vl" };	// different version installed
-  static const char * b[] = { "!",  "!R", "!l" };	//               / broken
+  static const char * _[] = { " ",  " l", " P", " R" };	// not installed / not relevant
+  static const char * i[] = { "i",  "il", "iP", "iR" };	// installed     / satisfied
+  static const char * I[] = { "i+", "il", "iP", "iR" };	// user installed
+  static const char * v[] = { "v",  "vl", "vP", "vR" };	// different version installed
+  static const char * b[] = { "!",  "!l", "!P", "!R" };	//               / broken
 
   const char ** stem = _;
   const ResStatus & status { pi_r.status() };
@@ -842,17 +848,21 @@ const char * computeStatusIndicator( const PoolItem & pi_r, ui::Selectable::cons
   }
   // and now the details
   if ( iType_r ) *iType_r = ( *(stem[0]) == 'i' );
-  return stem[pi_r.isRetracted() ? 1 : status.isLocked() ? 2 : 0];
+  if ( pi_r.isBlacklisted() )
+    return stem[pi_r.isPtf() ? 2 : 3];
+  if ( status.isLocked() )
+    return stem[1];
+  return stem[0];
 }
 
 const char * computeStatusIndicator( const ui::Selectable & sel_r, bool tagForeign_r, bool * iType_r )
 {
-  static const char * _[] = { " ",  " R", " l" };	// not installed / not relevant
-  static const char * i[] = { "i",  "iR", "il" };	// installed     / satisfied
-  static const char * I[] = { "i+", "iR", "il" };	// user installed
-  static const char * v[] = { "v",  "vR", "vl" };	// foreign installed
-  static const char * V[] = { "v+", "vR", "vl" };	// foreign user installed
-  static const char * b[] = { "!",  "!R", "!l" };	//               / broken
+  static const char * _[] = { " ",  " l", " P", " R" };	// not installed / not relevant
+  static const char * i[] = { "i",  "il", "iP", "iR" };	// installed     / satisfied
+  static const char * I[] = { "i+", "il", "iP", "iR" };	// user installed
+  static const char * v[] = { "v",  "vl", "vP", "vR" };	// foreign installed
+  static const char * V[] = { "v+", "vl", "vP", "vR" };	// foreign user installed
+  static const char * b[] = { "!",  "!l", "!P", "!R" };	//               / broken
 
   const char ** stem = _;
 
@@ -876,5 +886,9 @@ const char * computeStatusIndicator( const ui::Selectable & sel_r, bool tagForei
   // else _
   // and now the details
   if ( iType_r ) *iType_r = ( *(stem[0]) == 'i' );
-  return stem[sel_r.hasRetractedInstalled() ? 1 : sel_r.locked() ? 2 : 0];
+  if ( sel_r.hasBlacklistedInstalled() )
+    return stem[sel_r.hasPtfInstalled() ? 2 : 3];
+  if ( sel_r.locked() )
+    return stem[1];
+  return stem[0];
 }
